==> pynfe-5.0.21.tar.gz: pynfe-5.0.21/pynfe/mdfe/manual_300/webservices.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2018 All Rights Reserved. Luiz Fernando Maciel Franca
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2018, Creative Commons
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""

# Ambiente
PRODUCAO = 1
HOMOLOGACAO = 2

# Servicos do Webservice
MDFE_RECEPCAO = 1
MDFE_RET_RECEPCAO = 2
MDFE_RECEPCAO_EVENTO = 3
MDFE_CONSULTA = 4
MDFE_STATUS_SERVICO = 5
MDFE_CONS_NAO_ENC = 6

# Estados
RS = 43
MG = 31

WEBSERVICE = {
    RS: {
        PRODUCAO: {
            MDFE_RECEPCAO: {
                'url': 'https://mdfe.svrs.rs.gov.br/ws/MDFeRecepcao/MDFeRecepcao.asmx',
                'servico': 'MDFeRecepcao',
                'metodo': 'mdfeRecepcaoLote'
            },
            MDFE_RET_RECEPCAO: {
                'url': 'https://mdfe.svrs.rs.gov.br/ws/MDFeRetRecepcao/MDFeRetRecepcao.asmx',
                'servico': 'MDFeRetRecepcao',
                'metodo': 'mdfeRetRecepcao'
            },
            MDFE_RECEPCAO_EVENTO: {
                'url': 'https://mdfe.svrs.rs.gov.br/ws/MDFeRecepcaoEvento/MDFeRecepcaoEvento.asmx',
                'servico': 'MDFeRecepcaoEvento',
                'metodo': 'mdfeRecepcaoEvento'
            },
            MDFE_CONSULTA: {
                'url': 'https://mdfe.svrs.rs.gov.br/ws/MDFeConsulta/MDFeConsulta.asmx',
                'servico': 'MDFeConsulta',
                'metodo': 'mdfeConsultaMDF'
            },
            MDFE_STATUS_SERVICO: {
                'url': 'https://mdfe.svrs.rs.gov.br/ws/MDFeStatusServico/MDFeStatusServico.asmx',
                'servico': 'MDFeStatusServico',
                'metodo': 'mdfeStatusServicoMDF'
            },
            MDFE_CONS_NAO_ENC: {
                'url': 'https://mdfe.svrs.rs.gov.br/ws/MDFeConsNaoEnc/MDFeConsNaoEnc.asmx',
                'servico': 'MDFeConsNaoEnc',
                'metodo': 'mdfeConsultaNaoEnc'
            }
        },
        HOMOLOGACAO: {
            MDFE_RECEPCAO: {
                'url': 'https://mdfe-homologacao.svrs.rs.gov.br/ws/MDFeRecepcao/MDFeRecepcao.asmx',
                'servico': 'MDFeRecepcao',
                'metodo': 'mdfeRecepcaoLote'
            },
            MDFE_RET_RECEPCAO: {
                'url': 'https://mdfe-homologacao.svrs.rs.gov.br/ws/MDFeRetRecepcao/MDFeRetRecepcao.asmx',
                'servico': 'MDFeRetRecepcao',
                'metodo': 'mdfeRetRecepcao'
            },
            MDFE_RECEPCAO_EVENTO: {
                'url': 'https://mdfe-homologacao.svrs.rs.gov.br/ws/MDFeRecepcaoEvento/MDFeRecepcaoEvento.asmx',
                'servico': 'MDFeRecepcaoEvento',
                'metodo': 'mdfeRecepcaoEvento'
            },
            MDFE_CONSULTA: {
                'url': 'https://mdfe-homologacao.svrs.rs.gov.br/ws/MDFeConsulta/MDFeConsulta.asmx',
                'servico': 'MDFeConsulta',
                'metodo': 'mdfeConsultaMDF'
            },
            MDFE_STATUS_SERVICO: {
                'url': 'https://mdfe-homologacao.svrs.rs.gov.br/ws/MDFeStatusServico/MDFeStatusServico.asmx',
                'servico': 'MDFeStatusServico',
                'metodo': 'mdfeStatusServicoMDF'
            },
            MDFE_CONS_NAO_ENC: {
                'url': 'https://mdfe-homologacao.svrs.rs.gov.br/ws/MDFeConsNaoEnc/MDFeConsNaoEnc.asmx',
                'servico': 'MDFeConsNaoEnc',
                'metodo': 'mdfeConsultaNaoEnc'
            }
        },
    }
}

WEBSERVICE[MG] = WEBSERVICE[RS]  # Minas Gerais utiliza os servicos do Rio Grande do Sul - SVRS

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:

==> pynfe-5.0.26.tar.gz: pynfe-5.0.26/pynfe/mdfe/manual_300/webservices.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2018 All Rights Reserved. Luiz Fernando Maciel Franca
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2018, Creative Commons
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""

# Ambiente
PRODUCAO = 1
HOMOLOGACAO = 2

# Servicos do Webservice
MDFE_RECEPCAO = 1
MDFE_RET_RECEPCAO = 2
MDFE_RECEPCAO_EVENTO = 3
MDFE_CONSULTA = 4
MDFE_STATUS_SERVICO = 5
MDFE_CONS_NAO_ENC = 6

# Estados
RS = 43
MG = 31

WEBSERVICE = {
    RS: {
        PRODUCAO: {
            MDFE_RECEPCAO: {
                'url': 'https://mdfe.svrs.rs.gov.br/ws/MDFeRecepcaoSinc/MDFeRecepcaoSinc.asmx',
                'servico': 'MDFeRecepcaoSinc',
                'metodo': 'mdfeRecepcao'
            },
            MDFE_RET_RECEPCAO: {
                'url': 'https://mdfe.svrs.rs.gov.br/ws/MDFeRetRecepcao/MDFeRetRecepcao.asmx',
                'servico': 'MDFeRetRecepcao',
                'metodo': 'mdfeRetRecepcao'
            },
            MDFE_RECEPCAO_EVENTO: {
                'url': 'https://mdfe.svrs.rs.gov.br/ws/MDFeRecepcaoEvento/MDFeRecepcaoEvento.asmx',
                'servico': 'MDFeRecepcaoEvento',
                'metodo': 'mdfeRecepcaoEvento'
            },
            MDFE_CONSULTA: {
                'url': 'https://mdfe.svrs.rs.gov.br/ws/MDFeConsulta/MDFeConsulta.asmx',
                'servico': 'MDFeConsulta',
                'metodo': 'mdfeConsultaMDF'
            },
            MDFE_STATUS_SERVICO: {
                'url': 'https://mdfe.svrs.rs.gov.br/ws/MDFeStatusServico/MDFeStatusServico.asmx',
                'servico': 'MDFeStatusServico',
                'metodo': 'mdfeStatusServicoMDF'
            },
            MDFE_CONS_NAO_ENC: {
                'url': 'https://mdfe.svrs.rs.gov.br/ws/MDFeConsNaoEnc/MDFeConsNaoEnc.asmx',
                'servico': 'MDFeConsNaoEnc',
                'metodo': 'mdfeConsultaNaoEnc'
            }
        },
        HOMOLOGACAO: {
            MDFE_RECEPCAO: {
                'url': 'https://mdfe-homologacao.svrs.rs.gov.br/ws/MDFeRecepcaoSinc/MDFeRecepcaoSinc.asmx',
                'servico': 'MDFeRecepcaoSinc',
                'metodo': 'mdfeRecepcao'
            },
            MDFE_RET_RECEPCAO: {
                'url': 'https://mdfe-homologacao.svrs.rs.gov.br/ws/MDFeRetRecepcao/MDFeRetRecepcao.asmx',
                'servico': 'MDFeRetRecepcao',
                'metodo': 'mdfeRetRecepcao'
            },
            MDFE_RECEPCAO_EVENTO: {
                'url': 'https://mdfe-homologacao.svrs.rs.gov.br/ws/MDFeRecepcaoEvento/MDFeRecepcaoEvento.asmx',
                'servico': 'MDFeRecepcaoEvento',
                'metodo': 'mdfeRecepcaoEvento'
            },
            MDFE_CONSULTA: {
                'url': 'https://mdfe-homologacao.svrs.rs.gov.br/ws/MDFeConsulta/MDFeConsulta.asmx',
                'servico': 'MDFeConsulta',
                'metodo': 'mdfeConsultaMDF'
            },
            MDFE_STATUS_SERVICO: {
                'url': 'https://mdfe-homologacao.svrs.rs.gov.br/ws/MDFeStatusServico/MDFeStatusServico.asmx',
                'servico': 'MDFeStatusServico',
                'metodo': 'mdfeStatusServicoMDF'
            },
            MDFE_CONS_NAO_ENC: {
                'url': 'https://mdfe-homologacao.svrs.rs.gov.br/ws/MDFeConsNaoEnc/MDFeConsNaoEnc.asmx',
                'servico': 'MDFeConsNaoEnc',
                'metodo': 'mdfeConsultaNaoEnc'
            }
        },
    }
}

WEBSERVICE[MG] = WEBSERVICE[RS]  # Minas Gerais utiliza os servicos do Rio Grande do Sul - SVRS

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
